@@ -113,7 +113,10 @@ export const ReportForm = ({
     setRedirect(true);
     const createOrUpdate = !!report.id ? updateReport : createReport;
     await createOrUpdate({ ...report, state: ReportState.Draft });
-    reportInteraction('reports_draft_saved');
+    reportInteraction('reports_draft_saved', {
+      step: activeStep,
+      state: !!report.id ? report.state : 'new',
+    });
     clearReportState();
   };
 
@@ -150,7 +153,9 @@ export const ReportForm = ({
 
   return (
     <form onSubmit={onSubmitCustom} className={styles.container}>
-      {!editMode && (
+      {editMode ? (
+        <EditActions disabled={disabled} />
+      ) : (
         <PageActions
           saveDraft={saveDraft}
           existingReport={existingReport}
@@ -158,11 +163,11 @@ export const ReportForm = ({
           activeStep={activeStep}
           disabled={disabled}
           onDiscard={discardChanges}
+          schedule={report.schedule}
         >
           {pageActions}
         </PageActions>
       )}
-      {editMode && <EditActions />}
       <FormPrompt
         confirmRedirect={!redirect && Boolean(confirmRedirect || isUpdated)}
         onDiscard={onReportDiscarded}
